/*****************************************************************************
 *   The proposed solution for LPCXpresso Experiment Kit, Lab 3a
 *
 *   Copyright(C) 2013, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/

#include "LPC11xx.h"
#include "type.h"
#include "board.h"
#include "gpio.h"
#include "delay.h"

//#define ADVANCE_WITH_DELAY
#define TIMEOUT_STEP_MS  10
#define TIMEOUT_MS       5000


int main (void)
{
  uint8_t  ledCounter;
  uint32_t timeout;

  //Set LED1-LED8 pins as outputs
  GPIOSetDir( LED1_PORT, LED1_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED1_PORT, LED1_PIN, LED_OFF);
  GPIOSetDir( LED2_PORT, LED2_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED2_PORT, LED2_PIN, LED_OFF);
  GPIOSetDir( LED3_PORT, LED3_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED3_PORT, LED3_PIN, LED_OFF);
  GPIOSetDir( LED4_PORT, LED4_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED4_PORT, LED4_PIN, LED_OFF);
  GPIOSetDir( LED5_PORT, LED5_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED5_PORT, LED5_PIN, LED_OFF);
  GPIOSetDir( LED6_PORT, LED6_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED6_PORT, LED6_PIN, LED_OFF);
  GPIOSetDir( LED7_PORT, LED7_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED7_PORT, LED7_PIN, LED_OFF);
  GPIOSetDir( LED8_PORT, LED8_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED8_PORT, LED8_PIN, LED_OFF);

  //Set SW2/SW3 pins as inputs
  GPIOSetDir( SW2_PORT, SW2_PIN, GPIO_INPUT);
  GPIOSetDir( SW3_PORT, SW3_PIN, GPIO_INPUT);

  //Extra, turn buzzer off
  GPIOSetDir( BUZZ_PORT, BUZZ_PIN, GPIO_OUTPUT);
  GPIOSetValue( BUZZ_PORT, BUZZ_PIN, BUZZ_OFF);

  //enter forever loop
  ledCounter = 0;
  while (1)
  {
#ifdef ADVANCE_WITH_DELAY
	//delay a specified period of time (the sample period)
	delayMS(125);
#else
    //check if push-button is pressed
    timeout = 0;
    while (( GPIOGetValue(SW2_PORT, SW2_PIN) != SW_PRESSED) && (timeout < TIMEOUT_MS))
    {
      timeout += TIMEOUT_STEP_MS;
      delayMS(TIMEOUT_STEP_MS);
    }

    //wait until push-button is released
    do
    {
      delayMS(80);
    } while(GPIOGetValue(SW2_PORT, SW2_PIN) == SW_PRESSED);
#endif

    //update LED state
    ledCounter++;
    if (ledCounter >= 8)
      ledCounter = 0;

    //update LEDs
    GPIOSetValue( LED1_PORT, LED1_PIN, LED_OFF);
    GPIOSetValue( LED2_PORT, LED2_PIN, LED_OFF);
    GPIOSetValue( LED3_PORT, LED3_PIN, LED_OFF);
    GPIOSetValue( LED4_PORT, LED4_PIN, LED_OFF);
    GPIOSetValue( LED5_PORT, LED5_PIN, LED_OFF);
    GPIOSetValue( LED6_PORT, LED6_PIN, LED_OFF);
    GPIOSetValue( LED7_PORT, LED7_PIN, LED_OFF);
    GPIOSetValue( LED8_PORT, LED8_PIN, LED_OFF);
    switch(ledCounter)
    {
      case 0: GPIOSetValue( LED1_PORT, LED1_PIN, LED_ON); break;
      case 1: GPIOSetValue( LED2_PORT, LED2_PIN, LED_ON); break;
      case 2: GPIOSetValue( LED3_PORT, LED3_PIN, LED_ON); break;
      case 3: GPIOSetValue( LED4_PORT, LED4_PIN, LED_ON); break;
      case 4: GPIOSetValue( LED5_PORT, LED5_PIN, LED_ON); break;
      case 5: GPIOSetValue( LED6_PORT, LED6_PIN, LED_ON); break;
      case 6: GPIOSetValue( LED7_PORT, LED7_PIN, LED_ON); break;
      case 7: GPIOSetValue( LED8_PORT, LED8_PIN, LED_ON); break;
      default: break;
    }

  }

  return 0;
}
