/*****************************************************************************
 *   The proposed solution for LPCXpresso Experiment Kit, Lab 3b
 *
 *   Copyright(C) 2013, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/

#include "LPC11xx.h"
#include "type.h"
#include "board.h"
#include "gpio.h"
#include "delay.h"

int main (void)
{
  uint8_t ledCounter;
  uint8_t direction;
  uint8_t rate;
  uint8_t active;

  //Set LED1-LED8 pins as outputs
  GPIOSetDir( LED1_PORT, LED1_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED1_PORT, LED1_PIN, LED_OFF);
  GPIOSetDir( LED2_PORT, LED2_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED2_PORT, LED2_PIN, LED_OFF);
  GPIOSetDir( LED3_PORT, LED3_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED3_PORT, LED3_PIN, LED_OFF);
  GPIOSetDir( LED4_PORT, LED4_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED4_PORT, LED4_PIN, LED_OFF);
  GPIOSetDir( LED5_PORT, LED5_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED5_PORT, LED5_PIN, LED_OFF);
  GPIOSetDir( LED6_PORT, LED6_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED6_PORT, LED6_PIN, LED_OFF);
  GPIOSetDir( LED7_PORT, LED7_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED7_PORT, LED7_PIN, LED_OFF);
  GPIOSetDir( LED8_PORT, LED8_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED8_PORT, LED8_PIN, LED_OFF);

  //Set SW1-SW5 pins as inputs
  GPIOSetDir( SW1_PORT, SW1_PIN, GPIO_INPUT);
  GPIOSetDir( SW2_PORT, SW2_PIN, GPIO_INPUT);
  GPIOSetDir( SW3_PORT, SW3_PIN, GPIO_INPUT);
  GPIOSetDir( SW4_PORT, SW4_PIN, GPIO_INPUT);
  GPIOSetDir( SW5_PORT, SW5_PIN, GPIO_INPUT);

  //Extra, turn buzzer off
  GPIOSetDir( BUZZ_PORT, BUZZ_PIN, GPIO_OUTPUT);
  GPIOSetValue( BUZZ_PORT, BUZZ_PIN, BUZZ_OFF);

  //enter forever loop
  ledCounter = 0;
  rate = 8;
  direction = 0;
  active = 1;
  while (1)
  {
    //check if SW1 is pressed
    if (GPIOGetValue(SW1_PORT, SW1_PIN) == SW_PRESSED)
    {
        //increase rate
        if (rate > 5)
          rate--;

        //wait until push-button is released
        do
        {
          delayMS(20);
        } while(GPIOGetValue(SW1_PORT, SW1_PIN) == SW_PRESSED);
        delayMS(20);
    }

    //check if SW5 is pressed
    if (GPIOGetValue(SW5_PORT, SW5_PIN) == SW_PRESSED)
    {
        //decrease rate
        if (rate < 20)
          rate++;

        //wait until push-button is released
        do
        {
          delayMS(20);
        } while(GPIOGetValue(SW5_PORT, SW5_PIN) == SW_PRESSED);
        delayMS(20);
    }

    //check if SW2 is pressed
    if (GPIOGetValue(SW2_PORT, SW2_PIN) == SW_PRESSED)
    {
        //set direction
        direction = 0;

        //wait until push-button is released
        do
        {
          delayMS(20);
        } while(GPIOGetValue(SW2_PORT, SW2_PIN) == SW_PRESSED);
        delayMS(20);
    }

    //check if SW4 is pressed
    if (GPIOGetValue(SW4_PORT, SW4_PIN) == SW_PRESSED)
    {
        //set direction
        direction = 1;

        //wait until push-button is released
        do
        {
          delayMS(20);
        } while(GPIOGetValue(SW4_PORT, SW4_PIN) == SW_PRESSED);
        delayMS(20);
    }

    //check if SW3 is pressed
    if (GPIOGetValue(SW3_PORT, SW3_PIN) == SW_PRESSED)
    {
        //toggle active
        if (active == 0)
          active = 1;
        else
          active = 0;

        //wait until push-button is released
        do
        {
          delayMS(20);
        } while(GPIOGetValue(SW3_PORT, SW3_PIN) == SW_PRESSED);
        delayMS(20);
    }

    //delay
    delayMS(10*rate);


    //update LED state
    if (direction == 0)
    {
      ledCounter++;
      if (ledCounter >= 8)
        ledCounter = 0;
    }
    else
    {
      if (ledCounter > 0)
        ledCounter--;
      else
        ledCounter = 7;
    }

    //update LEDs
    GPIOSetValue( LED1_PORT, LED1_PIN, LED_OFF);
    GPIOSetValue( LED2_PORT, LED2_PIN, LED_OFF);
    GPIOSetValue( LED3_PORT, LED3_PIN, LED_OFF);
    GPIOSetValue( LED4_PORT, LED4_PIN, LED_OFF);
    GPIOSetValue( LED5_PORT, LED5_PIN, LED_OFF);
    GPIOSetValue( LED6_PORT, LED6_PIN, LED_OFF);
    GPIOSetValue( LED7_PORT, LED7_PIN, LED_OFF);
    GPIOSetValue( LED8_PORT, LED8_PIN, LED_OFF);
    if (active == 1)
      switch(ledCounter)
      {
        case 0: GPIOSetValue( LED1_PORT, LED1_PIN, LED_ON); break;
        case 1: GPIOSetValue( LED2_PORT, LED2_PIN, LED_ON); break;
        case 2: GPIOSetValue( LED3_PORT, LED3_PIN, LED_ON); break;
        case 3: GPIOSetValue( LED4_PORT, LED4_PIN, LED_ON); break;
        case 4: GPIOSetValue( LED5_PORT, LED5_PIN, LED_ON); break;
        case 5: GPIOSetValue( LED6_PORT, LED6_PIN, LED_ON); break;
        case 6: GPIOSetValue( LED7_PORT, LED7_PIN, LED_ON); break;
        case 7: GPIOSetValue( LED8_PORT, LED8_PIN, LED_ON); break;
        default: break;
      }

  }

  return 0;
}
