/*****************************************************************************
 *   The proposed solution for LPCXpresso Experiment Kit, Lab 6b
 *
 *   Copyright(C) 2013, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/

#include "LPC11xx.h"
#include "type.h"
#include "board.h"
#include "gpio.h"
#include "delay.h"
#include "adc.h"

int main (void)
{
  uint32_t analogValue;

  //Set LED1-LED8 pins as outputs
  GPIOSetDir( LED1_PORT, LED1_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED1_PORT, LED1_PIN, LED_OFF);
  GPIOSetDir( LED2_PORT, LED2_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED2_PORT, LED2_PIN, LED_OFF);
  GPIOSetDir( LED3_PORT, LED3_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED3_PORT, LED3_PIN, LED_OFF);
  GPIOSetDir( LED4_PORT, LED4_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED4_PORT, LED4_PIN, LED_OFF);
  GPIOSetDir( LED5_PORT, LED5_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED5_PORT, LED5_PIN, LED_OFF);
  GPIOSetDir( LED6_PORT, LED6_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED6_PORT, LED6_PIN, LED_OFF);
  GPIOSetDir( LED7_PORT, LED7_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED7_PORT, LED7_PIN, LED_OFF);
  GPIOSetDir( LED8_PORT, LED8_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED8_PORT, LED8_PIN, LED_OFF);

  //Set SW2/SW3 pins as inputs
  GPIOSetDir( SW2_PORT, SW2_PIN, GPIO_INPUT);
  GPIOSetDir( SW3_PORT, SW3_PIN, GPIO_INPUT);

  //Extra, turn buzzer off
  GPIOSetDir( BUZZ_PORT, BUZZ_PIN, GPIO_OUTPUT);
  GPIOSetValue( BUZZ_PORT, BUZZ_PIN, BUZZ_OFF);

  //Initialize ADC peripheral and pin-mixing
  ADCInit(4500000);  //4.5MHz ADC clock

  //get initial value
  analogValue = getADC(AIN2);   //AIN0 = trimming pot, AIN2 = light sensor

  while(1)
  {
    uint8_t wantedDutyCycle;
    uint8_t loopCounter;
    uint16_t adcCounter;
    uint16_t adcValue;

    //check if time to read analog input
    if (adcCounter++ > 1000)
    {
      adcCounter = 0;

      //Set wanted duty cycle - valid numbers: 0..100 (low number = LED on more)
//      wantedDutyCycle = getADC(AIN0) / 10;   //trimming pot
      adcValue = getADC(AIN2);   //light sensor   (dark is about 20, full light is 100-400)
      if (adcValue < 25)
        wantedDutyCycle = 0;
      else if (adcValue >= 225)
        wantedDutyCycle = 99;
      else
        wantedDutyCycle = (adcValue - 25) / 2;

      //extra check to that range is valid
      if (wantedDutyCycle > 99)
        wantedDutyCycle = 99;
    }

    //Set output high
    GPIOSetValue( LED1_PORT, LED1_PIN, 1);

    //Enter duty cycle generating loop (will give about 14 kHz PWM signal)
    for (loopCounter=0; loopCounter<100; loopCounter++)
    {
      if (loopCounter == wantedDutyCycle)
        //Set output low
        GPIOSetValue( LED1_PORT, LED1_PIN, 0);
    }
  }

  return 0;
}
