/*****************************************************************************
 *   The proposed solution for LPCXpresso Experiment Kit, Lab 8b
 *
 *   Copyright(C) 2013, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/

#include "LPC11xx.h"
#include "type.h"
#include "board.h"
#include "gpio.h"
#include "delay.h"
#include "adc.h"

#define SEG_A_PORT  LED1_PORT
#define SEG_A_PIN   LED1_PIN
#define SEG_B_PORT  LED2_PORT
#define SEG_B_PIN   LED2_PIN
#define SEG_C_PORT  LED3_PORT
#define SEG_C_PIN   LED3_PIN
#define SEG_D_PORT  PORT2
#define SEG_D_PIN   8
#define SEG_E_PORT  PORT2
#define SEG_E_PIN   9
#define SEG_F_PORT  LED6_PORT
#define SEG_F_PIN   LED6_PIN
#define SEG_G_PORT  LED7_PORT
#define SEG_G_PIN   LED7_PIN
#define SEG_DP_PORT LED8_PORT
#define SEG_DP_PIN  LED8_PIN

void setSegment(uint8_t value)
{
  GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_OFF);
  GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_OFF);
  GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_OFF);
  GPIOSetValue(SEG_D_PORT,SEG_D_PIN,LED_OFF);
  GPIOSetValue(SEG_E_PORT,SEG_E_PIN,LED_OFF);
  GPIOSetValue(SEG_F_PORT,SEG_F_PIN,LED_OFF);
  GPIOSetValue(SEG_G_PORT,SEG_G_PIN,LED_OFF);

  switch(value)
  {
  //0 = A,B,C,D,E,F
  case 0: GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_ON);
          GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          GPIOSetValue(SEG_D_PORT,SEG_D_PIN,LED_ON);
          GPIOSetValue(SEG_E_PORT,SEG_E_PIN,LED_ON);
          GPIOSetValue(SEG_F_PORT,SEG_F_PIN,LED_ON);
          break;
  //1 = B,C
  case 1: GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          break;
  //2 = A,B,D,E,G
  case 2: GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_ON);
          GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_ON);
          GPIOSetValue(SEG_D_PORT,SEG_D_PIN,LED_ON);
          GPIOSetValue(SEG_E_PORT,SEG_E_PIN,LED_ON);
          GPIOSetValue(SEG_G_PORT,SEG_G_PIN,LED_ON);
          break;
  //3 = A,B,C,D,G
  case 3: GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_ON);
          GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          GPIOSetValue(SEG_D_PORT,SEG_D_PIN,LED_ON);
          GPIOSetValue(SEG_G_PORT,SEG_G_PIN,LED_ON);
          break;
  //4 = B,C,F,G
  case 4: GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          GPIOSetValue(SEG_F_PORT,SEG_F_PIN,LED_ON);
          GPIOSetValue(SEG_G_PORT,SEG_G_PIN,LED_ON);
          break;
  //5 = A,C,D,F,G
  case 5: GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          GPIOSetValue(SEG_D_PORT,SEG_D_PIN,LED_ON);
          GPIOSetValue(SEG_F_PORT,SEG_F_PIN,LED_ON);
          GPIOSetValue(SEG_G_PORT,SEG_G_PIN,LED_ON);
          break;
  //6 = A,C,D,E,F,G
  case 6: GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          GPIOSetValue(SEG_D_PORT,SEG_D_PIN,LED_ON);
          GPIOSetValue(SEG_E_PORT,SEG_E_PIN,LED_ON);
          GPIOSetValue(SEG_F_PORT,SEG_F_PIN,LED_ON);
          GPIOSetValue(SEG_G_PORT,SEG_G_PIN,LED_ON);
          break;
  //7 = A,B,C
  case 7: GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_ON);
          GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          break;
  //8 = A,B,C,D,E,F,G
  case 8: GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_ON);
          GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          GPIOSetValue(SEG_D_PORT,SEG_D_PIN,LED_ON);
          GPIOSetValue(SEG_E_PORT,SEG_E_PIN,LED_ON);
          GPIOSetValue(SEG_F_PORT,SEG_F_PIN,LED_ON);
          GPIOSetValue(SEG_G_PORT,SEG_G_PIN,LED_ON);
          break;
  //9 = A,B,C,D,F,G
  case 9: GPIOSetValue(SEG_A_PORT,SEG_A_PIN,LED_ON);
          GPIOSetValue(SEG_B_PORT,SEG_B_PIN,LED_ON);
          GPIOSetValue(SEG_C_PORT,SEG_C_PIN,LED_ON);
          GPIOSetValue(SEG_D_PORT,SEG_D_PIN,LED_ON);
          GPIOSetValue(SEG_F_PORT,SEG_F_PIN,LED_ON);
          GPIOSetValue(SEG_G_PORT,SEG_G_PIN,LED_ON);
          break;
  default: break;
  }
}

/*
 * Note that this experiment will not work after the components
 * have been soldered to the experiment board.
 */

int main (void)
{
  //Set segment A-G+DP pins as outputs
  GPIOSetDir( SEG_A_PORT, SEG_A_PIN, GPIO_OUTPUT);
  GPIOSetValue( SEG_A_PORT, SEG_A_PIN, LED_OFF);
  GPIOSetDir( SEG_B_PORT, SEG_B_PIN, GPIO_OUTPUT);
  GPIOSetValue( SEG_B_PORT, SEG_B_PIN, LED_OFF);
  GPIOSetDir( SEG_C_PORT, SEG_C_PIN, GPIO_OUTPUT);
  GPIOSetValue( SEG_C_PORT, SEG_C_PIN, LED_OFF);
  GPIOSetDir( SEG_D_PORT, SEG_D_PIN, GPIO_OUTPUT);
  GPIOSetValue( SEG_D_PORT, SEG_D_PIN, LED_OFF);
  GPIOSetDir( SEG_E_PORT, SEG_E_PIN, GPIO_OUTPUT);
  GPIOSetValue( SEG_E_PORT, SEG_E_PIN, LED_OFF);
  GPIOSetDir( SEG_F_PORT, SEG_F_PIN, GPIO_OUTPUT);
  GPIOSetValue( SEG_F_PORT, SEG_F_PIN, LED_OFF);
  GPIOSetDir( SEG_G_PORT, SEG_G_PIN, GPIO_OUTPUT);
  GPIOSetValue( SEG_G_PORT, SEG_G_PIN, LED_OFF);
  GPIOSetDir( SEG_DP_PORT, SEG_DP_PIN, GPIO_OUTPUT);
  GPIOSetValue( SEG_DP_PORT, SEG_DP_PIN, LED_OFF);

  //Set SW2/SW3 pins as inputs
  GPIOSetDir( SW2_PORT, SW2_PIN, GPIO_INPUT);
  GPIOSetDir( SW3_PORT, SW3_PIN, GPIO_INPUT);

  //Extra, turn buzzer off
  GPIOSetDir( BUZZ_PORT, BUZZ_PIN, GPIO_OUTPUT);
  GPIOSetValue( BUZZ_PORT, BUZZ_PIN, BUZZ_OFF);

  while(1)
  {
    uint8_t i;

    for(i=0; i<10; i++)
    {
      setSegment(i);
      GPIOSetValue( SEG_DP_PORT, SEG_DP_PIN, LED_ON);
      delayMS(100);
      GPIOSetValue( SEG_DP_PORT, SEG_DP_PIN, LED_OFF);
#if 0
      delayMS(900);
#else
      //wait until push-button is pressed
      while(GPIOGetValue(SW2_PORT, SW2_PIN) != SW_PRESSED)
        ;
#endif
    }
  }

  return 0;
}
