/*****************************************************************************
 *   The proposed solution for LPCXpresso Experiment Kit, Lab 8e
 *
 *   Copyright(C) 2013, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/

#include "LPC11xx.h"
#include "type.h"
#include "board.h"
#include "gpio.h"
#include "delay.h"
#include "adc.h"

#define SCK_PORT    PORT2    //GPIO_3-SCK
#define SCK_PIN     11
#define MOSI_PORT   PORT0    //GPIO_1-MOSI
#define MOSI_PIN    9
#define SSEL_PORT   PORT0    //GPIO_4-LED-SSEL
#define SSEL_PIN    2

#define SEG_A   0x01
#define SEG_B   0x02
#define SEG_C   0x04
#define SEG_D   0x08
#define SEG_E   0x10
#define SEG_F   0x20
#define SEG_G   0x40

const uint8_t segments[10] = {
    SEG_A | SEG_B | SEG_C | SEG_D | SEG_E | SEG_F        ,  //0 = A,B,C,D,E,F
            SEG_B | SEG_C                                ,  //1 = B,C
    SEG_A | SEG_B |         SEG_D | SEG_E |         SEG_G,  //2 = A,B,D,E,G
    SEG_A | SEG_B | SEG_C | SEG_D |                 SEG_G,  //3 = A,B,C,D,G
            SEG_B | SEG_C |                 SEG_F | SEG_G,  //4 = B,C,F,G
    SEG_A |         SEG_C | SEG_D |         SEG_F | SEG_G,  //5 = A,C,D,F,G
    SEG_A |         SEG_C | SEG_D | SEG_E | SEG_F | SEG_G,  //6 = A,C,D,E,F,G
    SEG_A | SEG_B | SEG_C                                ,  //7 = A,B,C
    SEG_A | SEG_B | SEG_C | SEG_D | SEG_E | SEG_F | SEG_G,  //8 = A,B,C,D,E,F,G
    SEG_A | SEG_B | SEG_C | SEG_D |         SEG_F | SEG_G}; //9 = A,B,C,D,F,G

void updateShiftReg( uint8_t segments )
{
  uint8_t bitCnt;

  //Pull SCK and MOSI low, pull SSEL low
  GPIOSetValue( SCK_PORT, SCK_PIN, 0);
  GPIOSetValue( MOSI_PORT, MOSI_PIN, 0);
  GPIOSetValue( SSEL_PORT, SSEL_PIN, 0);

  //wait 1us
  delayUS(1);

  //Loop througth all eight bits
  for (bitCnt = 0; bitCnt < 8; bitCnt++)
  {
    //output MOSI value (bit 7 of “segments”)
    if (segments & 0x80)
      GPIOSetValue( MOSI_PORT, MOSI_PIN, 1);
    else
      GPIOSetValue( MOSI_PORT, MOSI_PIN, 0);

    //wait 1us
    delayUS(1);

    //pull SCK high
    GPIOSetValue( SCK_PORT, SCK_PIN, 1);

    //wait 1us
    delayUS(1);

    //pull SCK low
    GPIOSetValue( SCK_PORT, SCK_PIN, 0);

   //shift “segments”
    segments = segments << 1;
  }

  //Pull SSEL high
  GPIOSetValue( SSEL_PORT, SSEL_PIN, 1);
}

uint8_t convert00_99(uint16_t inputVal)
{
  return (inputVal * 100) / 1024;
}

int main (void)
{
  uint32_t analogValue;

  //setup pins for controlling 7-segment display
  GPIOSetDir( DIG1_PORT, DIG1_PIN, GPIO_OUTPUT);
  GPIOSetValue( DIG1_PORT, DIG1_PIN, 1);
  GPIOSetDir( DIG2_PORT, DIG2_PIN, GPIO_OUTPUT);
  GPIOSetValue( DIG2_PORT, DIG2_PIN, 1);

  GPIOSetDir( SCK_PORT, SCK_PIN, GPIO_OUTPUT);
  GPIOSetValue( SCK_PORT, SCK_PIN, 0);
  GPIOSetDir( MOSI_PORT, MOSI_PIN, GPIO_OUTPUT);
  GPIOSetValue( MOSI_PORT, MOSI_PIN, 0);
  GPIOSetDir( SSEL_PORT, SSEL_PIN, GPIO_OUTPUT);
  GPIOSetValue( SSEL_PORT, SSEL_PIN, 1);

  //Set SW2/SW3 pins as inputs
  GPIOSetDir( SW2_PORT, SW2_PIN, GPIO_INPUT);
  GPIOSetDir( SW3_PORT, SW3_PIN, GPIO_INPUT);

  //Extra, turn buzzer off
  GPIOSetDir( BUZZ_PORT, BUZZ_PIN, GPIO_OUTPUT);
  GPIOSetValue( BUZZ_PORT, BUZZ_PIN, BUZZ_OFF);

  //Initialize ADC peripheral and pin-mixing
  ADCInit(4500000);  //4.5MHz ADC clock

  //get initial value
  analogValue = getADC(AIN0);   //AIN0 = trimming pot for intensity

  while(1)
  {
    uint8_t outputValue;

    outputValue = convert00_99(getADC(AIN0));

    GPIOSetValue( DIG1_PORT, DIG1_PIN, 1);
    updateShiftReg(~segments[outputValue % 10]);
    GPIOSetValue( DIG2_PORT, DIG2_PIN, 0);
    delayMS(5);
    GPIOSetValue( DIG2_PORT, DIG2_PIN, 1);
    updateShiftReg(~segments[outputValue / 10]);
    GPIOSetValue( DIG1_PORT, DIG1_PIN, 0);
    delayMS(5);
  }

  return 0;
}
