/*****************************************************************************
 *   The proposed solution for LPCXpresso Experiment Kit, Lab 12a
 *
 *   Copyright(C) 2013, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/

#include "LPC11xx.h"
#include "type.h"
#include "board.h"
#include "gpio.h"
#include "delay.h"
#include "adc.h"
#include "pwm.h"
#include "spi.h"

/* Define Interrupt Service Routine for Port #1 */
void PIOINT1_IRQHandler (void)    //name of function is predefined
{
  static uint8_t ledState;

  /* toggle LED on PIO0_2 */
  if (ledState == 0)
  {
    ledState = 1;
    GPIOSetValue( LED1_PORT, LED1_PIN, LED_OFF);
  }
  else
  {
    ledState = 0;
    GPIOSetValue( LED1_PORT, LED1_PIN, LED_ON);
  }

  //clear PIO1_5 falling edge interrupt
  LPC_GPIO1->IC = (1<<5);   //write with bit 5 set to clear interrupt from PIO1_5
}

int main (void)
{
  //Set LED1-LED8 pins as outputs
  GPIOSetDir( LED1_PORT, LED1_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED1_PORT, LED1_PIN, LED_OFF);
  GPIOSetDir( LED2_PORT, LED2_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED2_PORT, LED2_PIN, LED_OFF);
  GPIOSetDir( LED3_PORT, LED3_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED3_PORT, LED3_PIN, LED_OFF);
  GPIOSetDir( LED4_PORT, LED4_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED4_PORT, LED4_PIN, LED_OFF);
  GPIOSetDir( LED5_PORT, LED5_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED5_PORT, LED5_PIN, LED_OFF);
  GPIOSetDir( LED6_PORT, LED6_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED6_PORT, LED6_PIN, LED_OFF);
  GPIOSetDir( LED7_PORT, LED7_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED7_PORT, LED7_PIN, LED_OFF);
  GPIOSetDir( LED8_PORT, LED8_PIN, GPIO_OUTPUT);
  GPIOSetValue( LED8_PORT, LED8_PIN, LED_OFF);

  //Set SW2/SW3 pins as inputs
  GPIOSetDir( SW2_PORT, SW2_PIN, GPIO_INPUT);
  GPIOSetDir( SW3_PORT, SW3_PIN, GPIO_INPUT);

  //Extra, turn buzzer pin to input
  GPIOSetDir( BUZZ_PORT, BUZZ_PIN, GPIO_OUTPUT);
  GPIOSetValue( BUZZ_PORT, BUZZ_PIN, BUZZ_OFF);

  /* initialize so that PIO1_5 generate an interrupt (falling edge sensitive). SW2 is connected to PIO1_5 */
  LPC_GPIO1->IEV &= ~(1<<5);   //clear bit 5 to set falling edge sensitive
  LPC_GPIO1->IE  |=  (1<<5);   //set bit 5 to enable interrupt from PIO1_5

  /* enable port #1 interrupt */
  NVIC_EnableIRQ(EINT1_IRQn);

  /* enter forever
   *  loop – let interrupt handle processing */
  while(1)
    ;      //here is a potential to go into a low power mode

  return 0;
}
