/*****************************************************************************
 *   Placeholder for LM75 related functions.
 *   Part of the proposed solutions for LPCXpresso Experiment Kit
 *
 *   Copyright(C) 2013, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/

#include "LPC11xx.h"
#include "type.h"
#include "i2c.h"
#include "lm75.h"

#define LM75B_I2C_ADDR  0x90
#define LM75B_REG_TEMP  0x00
#define LM75B_REG_CMD   0x01

/******************************************************************************
 *
 * Description:
 *    Read temperature register of LM75B
 *
 * Params:  None
 * Returns: Temperature * 100 in integer format
 *
 *****************************************************************************/
int32_t lm75b_readTemp(void)
{
  uint8_t cmd, temp[2];
  int32_t t = 0;

  cmd = LM75B_REG_TEMP;
  I2CWrite(LM75B_I2C_ADDR, &cmd,     1);
  I2CRead( LM75B_I2C_ADDR, &temp[0], 2);

  /* 11 MSB bits used. Celcius is calculated as Temp data * 1/8 */
  t = ((temp[0] << 8) | (temp[1]));

  /* Return temperature times 100, e.g., in 0.01 degrees */
  return (t * 100) >> 8;
}

/******************************************************************************
 *
 * Description:
 *    Write to config register of LM75B
 *
 * Params:  Config byte
 * Returns: None
 *
 *****************************************************************************/
void lm75b_config(int8_t config)
{
  uint8_t cmd[2];

  cmd[0] = LM75B_REG_CMD;
  cmd[1] = config;

  I2CWrite(LM75B_I2C_ADDR, &cmd[0], 2);
}
