/*****************************************************************************
 *   Placeholder for UART related functions.
 *   Part of the proposed solutions for LPCXpresso Experiment Kit
 *
 *   Copyright(C) 2013, Embedded Artists AB
 *   All rights reserved.
 *
 ******************************************************************************/
#ifndef __UART_H__
#define __UART_H__

#include "type.h"

//size of transmit buffer - size MUST be power of two
#define TX_BUFFER_SIZE 256
#define TX_BUFFER_MASK (TX_BUFFER_SIZE-1)

//size of receive buffer - size MUST be power of two
#define RX_BUFFER_SIZE 256
#define RX_BUFFER_MASK (RX_BUFFER_SIZE-1)

#define LSR_RDR    0x01
#define LSR_OE     0x02
#define LSR_PE     0x04
#define LSR_FE     0x08
#define LSR_BI     0x10
#define LSR_THRE   0x20
#define LSR_TEMT   0x40
#define LSR_RXFE   0x80

#define IER_RBR    0x01
#define IER_THRE   0x02
#define IER_RLS    0x04

#define IIR_PEND   0x01
#define IIR_RLS    0x03
#define IIR_RDA    0x02
#define IIR_CTI    0x06
#define IIR_THRE   0x01

/*****************************************************************************
** Function name:  UARTInit
**
** Descriptions:   Initialize UART0 port, setup pin select,
**                 clock, parity, stop bits, FIFO, etc.
**
** parameters:     UART baudrate
** Returned value: None
**
*****************************************************************************/
void UARTInit(uint32_t baudrate);

/*****************************************************************************
 ** Function name:  UARTSendChar
 **
 ** Descriptions:   Send a byte/char of data to the UART 0 port
 **
 ** parameters:     byte to send
 ** Returned value: None
 **
 *****************************************************************************/
void UARTSendChar(uint8_t toSend);

/*****************************************************************************
 ** Function name:  UARTSendString
 **
 ** Descriptions:   Send a null-terminated string to UART 0 port
 **
 ** parameters:     byte to send
 ** Returned value: None
 **
 *****************************************************************************/
void UARTSendString(uint8_t *pStr);

/*****************************************************************************
 ** Function name:  UARTSendBuffer
 **
 ** Descriptions:   Send a number of bytes/chars of data to UART 0 port
 **
 ** parameters:     byte to send
 ** Returned value: None
 **
 *****************************************************************************/
void UARTSendBuffer(uint8_t *pBuf, uint16_t length);

/*****************************************************************************
 ** Function name:  UARTGetCharBlock
 **
 ** Descriptions:   Receive a char from UART 0
 **
 ** parameters:     None
 ** Returned value: Received char
 **
 *****************************************************************************/
uint8_t UARTGetCharBlock(void);

/*****************************************************************************
 ** Function name:  UARTGetChar
 **
 ** Descriptions:   Receive a char from UART 0
 **
 ** parameters:     pointer to where to store received char
 ** Returned value: TRUE if char received, else FALSE
 **
 *****************************************************************************/
uint8_t UARTGetChar(uint8_t *pRxChar);

#endif /* __UART_H__ */
